<?php
class ExternalImage {
  static function render($input, $argv, $parser) {
    global $wgUrlProtocols;

    // Build array of valid attributes passed to us
    $validAttributes = array();

    foreach ($argv as $attribute => $value) {
      $error = false;

      // Check attributes for validity and security
      switch ($attribute) {
      case 'src':
	// Make sure it's an acceptable URL for this wiki
	$regex = sprintf("/^%s/", wfUrlProtocols());
	if (!preg_match($regex, $value)) {
	  error_log("Skipping Illegal src = '$value'");
	  $error = true;
	}
	break;

      case 'height':
      case 'width':
	// Make sure value is an integer
	if (!preg_match('/^\d+$/', $value)) {
	  error_log("Skipping attribute $attribute = '$value'");
	  $error = true;
	}
	break;

      default:
	error_log("Skipping unknown attribute $attribute = '$value'");
	$error = true;
      }

      // If we got here, we have a valid attribute and value
      if (! $error) {
	$validAttributes[$attribute] = $value;
      }
    }

    // Use MediaWiki's Xml class to generate the
    // img tag and sanitize/escape all values
    $imgTag = Xml::element('img', $validAttributes);

    // Sanitize and prepend the caption ($input).
    return sprintf("%s: %s", htmlspecialchars($input), $imgTag);
  }
}
