<?php
class FancyForm extends SpecialPage {
  const PARAM_USER = 'user';

  function __construct() {
    SpecialPage::SpecialPage('FancyForm');
    wfLoadExtensionMessages('FancyForm');
  }

  function execute( $par ) {
    global $wgRequest;
    
    $this->setHeaders();

    $results = '';
    if ($wgRequest->wasPosted()) {
      // Form POST
      $username = $wgRequest->getText(self::PARAM_USER);
      $this->processForm($username);
    } elseif ($par) {
      // Parameter passed in the URL
      $this->processForm($par);
    } else {
      // Just display the form
      $this->displayForm();
    }
  }

  function processForm($username) {
    global $wgOut;
    $error = false;

    // Create a user object
    $user = User::newFromName($username);
    if (is_null($user)) {
      // Invalid username
      $wgOut->addWikiMsg('fancyform-error-invalid',
			 wfEscapeWikiText($username));
      $error = true;
    } elseif ($user->idForName() == 0) {
      // No such user in database
      $wgOut->addWikiMsg('fancyform-error-none',
			 wfEscapeWikiText($username));
      $error = true;
    } else {
      // Display info in a bulleted list.
      // Xml class automatically sanitizes/escapes the input.
      $html = Xml::element('h2',
			   null,
			   wfMsg('fancyform-hello', $username))
	. Xml::openElement('ul')
	. Xml::element('li',
		       null,
		       wfMsg('yourrealname') . ' ' . $user->getRealName())
	. Xml::element('li',
		       null,
		       wfMsg('youremail') . ' ' . $user->getEmail())
	. Xml::closeElement('ul')
	;
      $wgOut->addHTML($html);
    }

    // On error, repeat the form
    if ($error) {
      $this->displayForm();
    }
  }

  function displayForm() {
    global $wgOut, $wgScript, $wgTitle;

    $html = Xml::openElement('form',
			      array(
				    'method' => 'post',
				    'action' => $wgScript
				    ))
      . Xml::element('p', null, wfMsg('fancyform-prompt'))
      . Xml::input(self::PARAM_USER)
      . Xml::submitButton(wfMsg('fancyform-submit'))
      . Xml::hidden('title', $wgTitle->getPrefixedDBkey())
      . Xml::closeElement('form')
      ;

    $wgOut->addHTML($html);
  }
}